Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
pydelica/__init__.py | Session | 212 | 95 | 0 | 55%
pydelica/__init__.py | (no class) | 69 | 0 | 0 | 100%
pydelica/compiler.py | Compiler | 137 | 51 | 0 | 63%
pydelica/compiler.py | (no class) | 20 | 0 | 0 | 100%
pydelica/exception.py | BinaryNotFoundError | 1 | 1 | 0 | 0%
pydelica/exception.py | OMParsingError | 1 | 0 | 0 | 100%
pydelica/exception.py | OMExecutionError | 1 | 0 | 0 | 100%
pydelica/exception.py | OMBuildError | 1 | 1 | 0 | 0%
pydelica/exception.py | OMAssertionError | 1 | 0 | 0 | 100%
pydelica/exception.py | NotImplementedError | 1 | 1 | 0 | 0%
pydelica/exception.py | UnknownParameterError | 2 | 2 | 0 | 0%
pydelica/exception.py | UnknownModelError | 2 | 2 | 0 | 0%
pydelica/exception.py | ResultRetrievalError | 2 | 2 | 0 | 0%
pydelica/exception.py | UnknownOptionError | 2 | 2 | 0 | 0%
pydelica/exception.py | ModelicaFileGenerationError | 1 | 1 | 0 | 0%
pydelica/exception.py | UnknownLibraryError | 1 | 1 | 0 | 0%
pydelica/exception.py | (no class) | 50 | 3 | 0 | 94%
pydelica/logger.py | OMLogLevel | 0 | 0 | 0 | 100%
pydelica/logger.py | (no class) | 11 | 0 | 0 | 100%
pydelica/model.py | Model | 54 | 12 | 0 | 78%
pydelica/model.py | (no class) | 21 | 0 | 0 | 100%
pydelica/options/__init__.py | (no class) | 5 | 0 | 0 | 100%
pydelica/options/library.py | LibrarySetup | 62 | 21 | 0 | 66%
pydelica/options/library.py | (no class) | 16 | 0 | 0 | 100%
pydelica/options/runtime.py | RuntimeOptions | 26 | 8 | 0 | 69%
pydelica/options/runtime.py | (no class) | 191 | 0 | 0 | 100%
pydelica/options/simulation.py | Solver | 0 | 0 | 0 | 100%
pydelica/options/simulation.py | OutputFormat | 0 | 0 | 0 | 100%
pydelica/options/simulation.py | SimulationOptions | 20 | 7 | 0 | 65%
pydelica/options/simulation.py | (no class) | 24 | 0 | 0 | 100%
pydelica/solutions.py | SolutionHandler | 12 | 1 | 0 | 92%
pydelica/solutions.py | (no class) | 8 | 0 | 0 | 100%
Total |  | 954 | 211 | 0 | 78%

No items found using the specified filter.